@@ -4,7 +4,7 @@
 # Based on yamas v0.9 by comaX for pcsci3ence.info
 
 #Version information
-version=0.9.7
+version=0.9.8
 
 # device variables
 pathLog=/home/user/yamas
@@ -79,8 +79,7 @@ dep() {
    fi
           
    echo -en "\t sslstrip\t"
-   # "sslstrip" package doesn't exist. One has to compile on target.
-   if [ -e "/usr/bin/sslstrip" ]; then          # therefore we do a simple check of existence
+   if dpkg -l | grep sslstrip 1>/dev/null; then 
      echo -e "\t\033[32m[Success]\033[m"
    else 
      echo -e "\t\033[31m[Failed!]\033[m"
@@ -175,9 +174,6 @@ usage : $0 <options>
              Don't use wildcards. Use > /output_file to print to a file.
    -v or --version : Show version and exit
 
-
-
-
 \033[31m DISCLAIMER :\033[m
 This program is intended for learning purpose only. I do not condone hacking 
 and wouldn't be held responsible for your actions. Only you would face legal
@@ -236,7 +232,7 @@ echo -e "\b
 =       Feel free to contribute and distribute this script as you please. =
 =       Official thread : http://tinyurl.com/yamas-arm                    =
 =       Check out the help (-h) to see edition informations               =
-=       You are running \033[32mYAMAS-arm\033[m                                  	  =
+=       You are running \033[32mYAMAS-arm\033[m                                       =
 
 ===========================================================================
 
@@ -296,7 +292,7 @@ cleanup() {
    echo "(If you want to keep it, it will be stored in $pathLog/saved/$filename.txt)"
    read keep
    if [[ "$keep" = "Y" || "$keep" = "y" ]] ; then # double brackets because double condition. || signifies "or"
-      mkdir $pathLog/saved/	
+      mkdir $pathLog/saved/   
       cp $pathLog/$filename.txt $pathLog/saved/$filename.txt #moving file
          if [ -f "$pathLog/saved/$filename.txt" ]; then #check if it exists
             echo "Log file copied !" #it does
@@ -491,7 +487,7 @@ echo
 
 if [[ "$choicearp" = "D" || "$choicearp" = "d" ]] ; then
    echo
-   echo -e "Do you want to map the network to show live hosts? (Y/N)	[This might take up to 30 secs, be patient]"
+   echo -e "Do you want to map the network to show live hosts? (Y/N)   [This might take up to 30 secs, be patient]"
    read hosts
    echo -e "\033[31m "
       if [[ "$hosts" = "Y" || "$hosts" = "y" ]] ; then
